@@ -3,12 +3,14 @@
 
 use std::fs::{read_to_string, remove_file, File, OpenOptions};
 use std::io::{BufRead, BufReader, Write};
+use std::iter::repeat;
 use std::path::{Path, PathBuf};
+use std::process::exit;
 use std::time::SystemTime;
 
 use log::{debug, error};
 
-use crate::util::consts::{ERR_NO_FILE, ERR_PARSE};
+use crate::util::consts::*;
 
 pub fn util_file_to_paths(path: &Path) -> Vec<PathBuf> {
     let file = File::open(path).expect(ERR_NO_FILE);
@@ -27,6 +29,15 @@ pub fn util_paths_to_file(paths: Vec<PathBuf>, out: &PathBuf) {
     util_lines_to_file(out, lines)
 }
 
+pub fn util_terminate_error(msg: &str) {
+    error!("{}", msg);
+    exit(1)
+}
+
+pub fn util_transform_idx(idx: usize) -> usize {
+    idx - 1
+}
+
 pub fn util_lines_to_file(out: &PathBuf, lines: Vec<String>) {
     let mut buf: String = lines.join("\n");
     if !buf.is_empty() {
@@ -70,6 +81,10 @@ pub fn util_append_file(path: &PathBuf, buffer: &String) {
     file.write(buffer.as_bytes());
 }
 
+pub fn util_horiz_rule() {
+    println!("{}", repeat(HR_CHAR).take(80).collect::<String>())
+}
+
 pub fn util_overwrite_file(path: &PathBuf, buffer: &String) {
     let mut file = OpenOptions::new()
         .create(true)
